@@ -27,14 +27,6 @@ pub(super) struct Preserver {
 impl Visit for Preserver {
     noop_visit_type!();
 
-    fn visit_class_decl(&mut self, n: &ClassDecl, _: &dyn Node) {
-        n.visit_children_with(self);
-
-        if (self.in_top_level && !self.options.top_level) || self.options.keep_class_names {
-            self.preserved.insert(n.ident.to_id());
-        }
-    }
-
     fn visit_catch_clause(&mut self, n: &CatchClause, _: &dyn Node) {
         let old = self.should_preserve;
 
@@ -47,6 +39,14 @@ impl Visit for Preserver {
         n.body.visit_with(&Invalid { span: DUMMY_SP }, self);
     }
 
+    fn visit_class_decl(&mut self, n: &ClassDecl, _: &dyn Node) {
+        n.visit_children_with(self);
+
+        if (self.in_top_level && !self.options.top_level) || self.options.keep_class_names {
+            self.preserved.insert(n.ident.to_id());
+        }
+    }
+
     fn visit_export_decl(&mut self, n: &ExportDecl, _: &dyn Node) {
         n.visit_children_with(self);
 
@@ -86,6 +86,16 @@ impl Visit for Preserver {
         }
     }
 
+    fn visit_fn_expr(&mut self, n: &FnExpr, _: &dyn Node) {
+        n.visit_children_with(self);
+
+        if self.options.keep_fn_names {
+            if let Some(i) = &n.ident {
+                self.preserved.insert(i.to_id());
+            }
+        }
+    }
+
     fn visit_member_expr(&mut self, n: &MemberExpr, _: &dyn Node) {
         n.obj.visit_with(n, self);
         if n.computed {
